const path = require('path');
const program = require('commander');
const { execSync } = require('child_process');
const moveFile = require('./helper/moveFile');
const myPackage = require('../package.json');
const createLogger = require('progress-estimator');
const cwd = process.cwd();
const pkg = require(path.join(cwd, 'package.json'));
const logger = createLogger();

program
  .version(myPackage.version);

const fileDir = path.join(cwd, '/dist');
const releaseDir = path.join(cwd, '/release');

// build
program
  .command('build <desc>')
  .action(async (desc) => {
    const build = async () => {
      await execSync('npm run build');
      return;
    }
    async function runBuild() {
      await logger(build(), "run build", {
        estimate: 10000
      });
    }
    await runBuild();

    // 移动文件夹
    async function runMoveFiles() {
      await logger(moveFile(fileDir, releaseDir), "move files", {
        estimate: 1000
      });
    }
    await runMoveFiles();
    
    // git release
    const gitRelease = async () => {
      execSync('git add .', { cwd: releaseDir });
      execSync(`git commit -m "${desc}, ${new Date().toLocaleString()}"`, { cwd: releaseDir });
      execSync(`git push origin master:${pkg.branch ? pkg.branch.release : 'release'}`, { cwd: releaseDir });
      return ;
    }
    async function runGit() {
      await logger(gitRelease(), "git release", {
        estimate: 2000
      });
    }
    await runGit();
  });

program.parse(process.argv);
